# Package description

# Version 0.0.3

This is a simple printer of nested lists in lists.


# Version 1.0.0

The module provides a function called print_lol(), which returns or not the items
in lists that may or may not include nested lists, and can be used with up to 3 arguments:
default (list), indented (list, True) or indented from a value (list, True, 2).
